@@ -993,18 +993,30 @@ void WTable::updatePots()
 	
 	
 	QString strPots;
+	chips_type pot_sum = 0;
 	if (snap->pots.at(0) > 0)
 	{
+		pot_sum += snap->pots.at(0);
+		
 		strPots = QString(tr("Main pot: %1").arg(snap->pots.at(0)));
 		for (unsigned int t = 1; t < snap->pots.size(); ++t)
 		{
+			pot_sum += snap->pots.at(t);
+			
 			strPots.append(
 				QString("  " + tr("Side pot %1: %2")
 					.arg(t).arg(snap->pots.at(t))));
 		}
 	}
 	
-	m_pTxtPots->setText(strPots);
+	QString strPotSum;
+	if (snap->state <= Table::Betting && currentPot() > 0)
+		strPotSum = QString("%1").arg(currentPot());
+	else if (pot_sum > 0)
+		strPotSum = QString("%1").arg(pot_sum);
+	
+	m_pTxtPots->setText(strPotSum);
+	m_pTxtPots->setToolTip(strPots);
 	m_pTxtPots->setPos(calcPotsPos());
 }
 
@@ -1592,7 +1604,7 @@ void WTable::actionChat(QString msg)
 void WTable::playSound(unsigned int id) const
 {
 #ifndef NOAUDIO
-	if (!config.getBool("sound") || (config.getBool("sound_focus") && !isActiveWindow()))
+	if (!config.getBool("sound") || isHidden() || (config.getBool("sound_focus") && !isActiveWindow()))
 		return;
 	
 	audio_play(id);
